DavoiceEventName enum

Names emitted by the native Davoice speech bridges.

Inheritance
Available extensions

Values

onSpeechStart → const DavoiceEventName
onSpeechRecognized → const DavoiceEventName
onSpeechEnd → const DavoiceEventName
onSpeechError → const DavoiceEventName
onSpeechResults → const DavoiceEventName
onSpeechPartialResults → const DavoiceEventName
onSpeechVolumeChanged → const DavoiceEventName
onNewSpeechWAV → const DavoiceEventName
onFinishedSpeaking → const DavoiceEventName

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

tryParse(String? value) DavoiceEventName?
Parses an event name from the native event payload.

Constants

values → const List<DavoiceEventName>
A constant List of the values in this enum, in order of their declaration.