DavoiceSpeechEvent class
A normalized event emitted by the native speech bridges.
Constructors
-
DavoiceSpeechEvent({required DavoiceEventName name, required Map<
String, dynamic> payload}) -
Creates a normalized speech event.
const
-
DavoiceSpeechEvent.fromMap(Map<
String, dynamic> map) -
Creates an event from an EventChannel payload.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → DavoiceEventName
-
Event name.
final
-
payload
→ Map<
String, dynamic> -
Original native payload.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited