DavoiceStartOptions class

Options for starting speech recognition.

Constructors

DavoiceStartOptions({String extraLanguageModel = 'LANGUAGE_MODEL_FREE_FORM', int extraMaxResults = 5, bool extraPartialResults = true, bool requestPermissionsAuto = true, Map<String, dynamic>? extra})
Creates speech recognition start options.
const

Properties

extra → Map<String, dynamic>?
Extra native options.
final
extraLanguageModel → String
Native Android language model option.
final
extraMaxResults → int
Native Android max results option.
final
extraPartialResults → bool
Native Android partial results option.
final
hashCode → int
The hash code for this object.
no setterinherited
requestPermissionsAuto → bool
Whether native Android should request permissions automatically.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts options to the native channel map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited