SpeechRecognizedEvent class

Speech recognition recognized-state event.

Constructors

SpeechRecognizedEvent({required bool isFinal})
Creates a recognized-state event.
const
SpeechRecognizedEvent.fromMap(Map<String, dynamic> map)
Creates the event from a native payload.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isFinal bool
Whether the recognizer considers the result final.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited