SpeechResultsEvent class

Speech recognition results event.

Constructors

SpeechResultsEvent({required List<String> value})
Creates a speech results event.
const
SpeechResultsEvent.fromMap(Map<String, dynamic> map)
Creates the event from a native payload.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value List<String>
Recognized text values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited