DavoiceExternalPcm class

External PCM descriptor passed to native playback.

Constructors

DavoiceExternalPcm({required String base64, required int sampleRate, required DavoicePcmFormat format, int channels = 1, bool interleaved = true, bool markAsLast = true})
Creates an external PCM descriptor.
const

Properties

base64 String
Base64-encoded raw PCM data.
final
channels int
Number of audio channels.
final
format DavoicePcmFormat
PCM sample format.
final
hashCode int
The hash code for this object.
no setterinherited
interleaved bool
Whether samples are interleaved.
final
markAsLast bool
Whether native should emit completion when this finishes.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate int
PCM sample rate.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Converts this descriptor to the native channel map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited